==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QSGDynamicTexture.java <==
package io.qt.quick;


/**
 * <p>Serves as a baseclass for dynamically changing textures, such as content that is rendered to FBO's</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qsgdynamictexture.html">QSGDynamicTexture</a></p>
 */
public abstract class QSGDynamicTexture extends io.qt.quick.QSGTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSGDynamicTexture.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGDynamicTexture {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void bind(){
            bind_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void bind_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean hasAlphaChannel(){
            return hasAlphaChannel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean hasAlphaChannel_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean hasMipmaps(){
            return hasMipmaps_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean hasMipmaps_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public int textureId(){
            return textureId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native int textureId_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QSize textureSize(){
            return textureSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QSize textureSize_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean updateTexture(){
            return updateTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean updateTexture_native(long __this__nativeId);
        
    }
    
    
    public QSGDynamicTexture(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGDynamicTexture instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgdynamictexture.html#updateTexture">QSGDynamicTexture::updateTexture()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean updateTexture();
    
    @io.qt.QtUninvokable
    private native boolean updateTexture_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGDynamicTexture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSGDynamicTexture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSGDynamicTexture instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QSGDynamicTexture.java <==
package io.qt.quick;


/**
 * <p>Serves as a baseclass for dynamically changing textures, such as content that is rendered to FBO's</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsgdynamictexture.html">QSGDynamicTexture</a></p>
 */
public abstract class QSGDynamicTexture extends io.qt.quick.QSGTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSGDynamicTexture.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGDynamicTexture {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public long comparisonKey(){
            return comparisonKey_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native long comparisonKey_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean hasAlphaChannel(){
            return hasAlphaChannel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean hasAlphaChannel_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean hasMipmaps(){
            return hasMipmaps_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean hasMipmaps_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QSize textureSize(){
            return textureSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QSize textureSize_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean updateTexture(){
            return updateTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native boolean updateTexture_native(long __this__nativeId);
        
    }
    
    
    public QSGDynamicTexture(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGDynamicTexture instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgdynamictexture.html#updateTexture">QSGDynamicTexture::updateTexture()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean updateTexture();
    
    @io.qt.QtUninvokable
    private native boolean updateTexture_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGDynamicTexture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSGDynamicTexture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSGDynamicTexture instance, QDeclarativeConstructor constructor);
    
}
